pub struct InterruptMask(/* private fields */);Expand description
中断状态标志
Implementations
Sourceimpl InterruptMask
impl InterruptMask
Sourcepub const RX_AVAILABLE: InterruptMask
pub const RX_AVAILABLE: InterruptMask
received data, including error data
pub const TX_EMPTY: InterruptMask
Sourceimpl InterruptMask
impl InterruptMask
Sourcepub const fn empty() -> InterruptMask
pub const fn empty() -> InterruptMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> InterruptMask
pub const fn all() -> InterruptMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<InterruptMask>
pub const fn from_bits(bits: u32) -> Option<InterruptMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> InterruptMask
pub const fn from_bits_truncate(bits: u32) -> InterruptMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> InterruptMask
pub const fn from_bits_retain(bits: u32) -> InterruptMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<InterruptMask>
pub fn from_name(name: &str) -> Option<InterruptMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: InterruptMask) -> bool
pub const fn intersects(&self, other: InterruptMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: InterruptMask) -> bool
pub const fn contains(&self, other: InterruptMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: InterruptMask)
pub fn insert(&mut self, other: InterruptMask)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: InterruptMask)
pub fn remove(&mut self, other: InterruptMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: InterruptMask)
pub fn toggle(&mut self, other: InterruptMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: InterruptMask, value: bool)
pub fn set(&mut self, other: InterruptMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: InterruptMask) -> InterruptMask
pub const fn intersection(self, other: InterruptMask) -> InterruptMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: InterruptMask) -> InterruptMask
pub const fn union(self, other: InterruptMask) -> InterruptMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: InterruptMask) -> InterruptMask
pub const fn difference(self, other: InterruptMask) -> InterruptMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: InterruptMask) -> InterruptMask
pub const fn symmetric_difference(self, other: InterruptMask) -> InterruptMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> InterruptMask
pub const fn complement(self) -> InterruptMask
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl InterruptMask
impl InterruptMask
Sourcepub const fn iter(&self) -> Iter<InterruptMask>
pub const fn iter(&self) -> Iter<InterruptMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<InterruptMask>
pub const fn iter_names(&self) -> IterNames<InterruptMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl InterruptMask
impl InterruptMask