OwnerLease

Struct OwnerLease 

pub struct OwnerLease<'a> { /* private fields */ }

Implementations

Source

impl<'a> OwnerLease<'a>

pub unsafe fn new_unchecked(owner: OwnerId) -> OwnerLease<'a>

Creates an owner lease.

Safety

The caller must be executing on owner, local IRQ/preemption state must prevent another owner lease from being created concurrently for the same UART, and no higher-priority FIQ/NMI/debug path may access this UART.

pub fn owner(&self) -> OwnerId