pub struct RxErrorFlags(/* private fields */);Expand description
RX error state reported by the IRQ endpoint while buffering samples.
Implementations
Sourceimpl RxErrorFlags
impl RxErrorFlags
pub const BREAK: RxErrorFlags
pub const PARITY: RxErrorFlags
pub const FRAMING: RxErrorFlags
pub const OVERRUN: RxErrorFlags
Sourceimpl RxErrorFlags
impl RxErrorFlags
Sourcepub const fn empty() -> RxErrorFlags
pub const fn empty() -> RxErrorFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> RxErrorFlags
pub const fn all() -> RxErrorFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<RxErrorFlags>
pub const fn from_bits(bits: u32) -> Option<RxErrorFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> RxErrorFlags
pub const fn from_bits_truncate(bits: u32) -> RxErrorFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> RxErrorFlags
pub const fn from_bits_retain(bits: u32) -> RxErrorFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RxErrorFlags>
pub fn from_name(name: &str) -> Option<RxErrorFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RxErrorFlags) -> bool
pub const fn intersects(&self, other: RxErrorFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RxErrorFlags) -> bool
pub const fn contains(&self, other: RxErrorFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RxErrorFlags)
pub fn insert(&mut self, other: RxErrorFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RxErrorFlags)
pub fn remove(&mut self, other: RxErrorFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RxErrorFlags)
pub fn toggle(&mut self, other: RxErrorFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RxErrorFlags, value: bool)
pub fn set(&mut self, other: RxErrorFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: RxErrorFlags) -> RxErrorFlags
pub const fn intersection(self, other: RxErrorFlags) -> RxErrorFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: RxErrorFlags) -> RxErrorFlags
pub const fn union(self, other: RxErrorFlags) -> RxErrorFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: RxErrorFlags) -> RxErrorFlags
pub const fn difference(self, other: RxErrorFlags) -> RxErrorFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: RxErrorFlags) -> RxErrorFlags
pub const fn symmetric_difference(self, other: RxErrorFlags) -> RxErrorFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RxErrorFlags
pub const fn complement(self) -> RxErrorFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RxErrorFlags
impl RxErrorFlags
Sourcepub const fn iter(&self) -> Iter<RxErrorFlags> ⓘ
pub const fn iter(&self) -> Iter<RxErrorFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RxErrorFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<RxErrorFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.