pub struct SerialEventSet(/* private fields */);Expand description
Stable event classes exchanged between a UART and its runtime.
Implementations
Sourceimpl SerialEventSet
impl SerialEventSet
pub const RX_DATA: SerialEventSet
pub const RX_TIMEOUT: SerialEventSet
pub const RX_STATUS: SerialEventSet
pub const TX_SPACE: SerialEventSet
pub const MODEM_STATUS: SerialEventSet
pub const BUSY_DETECT: SerialEventSet
pub const FAULT: SerialEventSet
pub const RX: SerialEventSet
Sourceimpl SerialEventSet
impl SerialEventSet
Sourcepub const fn empty() -> SerialEventSet
pub const fn empty() -> SerialEventSet
Get a flags value with all bits unset.
Sourcepub const fn all() -> SerialEventSet
pub const fn all() -> SerialEventSet
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SerialEventSet>
pub const fn from_bits(bits: u32) -> Option<SerialEventSet>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SerialEventSet
pub const fn from_bits_truncate(bits: u32) -> SerialEventSet
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SerialEventSet
pub const fn from_bits_retain(bits: u32) -> SerialEventSet
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SerialEventSet>
pub fn from_name(name: &str) -> Option<SerialEventSet>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SerialEventSet) -> bool
pub const fn intersects(&self, other: SerialEventSet) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SerialEventSet) -> bool
pub const fn contains(&self, other: SerialEventSet) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SerialEventSet)
pub fn insert(&mut self, other: SerialEventSet)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SerialEventSet)
pub fn remove(&mut self, other: SerialEventSet)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SerialEventSet)
pub fn toggle(&mut self, other: SerialEventSet)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SerialEventSet, value: bool)
pub fn set(&mut self, other: SerialEventSet, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SerialEventSet) -> SerialEventSet
pub const fn intersection(self, other: SerialEventSet) -> SerialEventSet
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SerialEventSet) -> SerialEventSet
pub const fn union(self, other: SerialEventSet) -> SerialEventSet
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SerialEventSet) -> SerialEventSet
pub const fn difference(self, other: SerialEventSet) -> SerialEventSet
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SerialEventSet) -> SerialEventSet
pub const fn symmetric_difference(self, other: SerialEventSet) -> SerialEventSet
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SerialEventSet
pub const fn complement(self) -> SerialEventSet
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SerialEventSet
impl SerialEventSet
Sourcepub const fn iter(&self) -> Iter<SerialEventSet>
pub const fn iter(&self) -> Iter<SerialEventSet>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SerialEventSet>
pub const fn iter_names(&self) -> IterNames<SerialEventSet>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.